@@ -5,7 +5,8 @@ test_that("webtris_sites() returns dataframe", {
     x <- webtris_sites()
     
     expect_is(x, class = "data.frame")
-    expected_cols <- c("Id", "Name", "Description", "Longitude", "Latitude", "Status")
+    expected_cols <- c("Id", "Name", "Description", "Longitude", 
+        "Latitude", "Status")
     expect_equivalent(expected_cols, colnames(x))
 })
 
@@ -15,6 +16,7 @@ test_that("webtris_quality(daily=FALSE) returns dataframe", {
     
     
     expect_is(x, class = "data.frame")
-    expected_cols <- c("Id", "Name", "Description", "Longitude", "Latitude", "Status")
+    expected_cols <- c("Id", "Name", "Description", "Longitude", 
+        "Latitude", "Status")
     expect_equivalent(expected_cols, colnames(x))
 })
